@@ -2,7 +2,7 @@ GeomBar <- proto(Geom, {
   
   default_stat <- function(.) StatBin
   default_pos <- function(.) PositionStack
-  default_aes <- function(.) aes(colour=NA, fill="grey60", size=0.5, linetype=1, weight = 1)
+  default_aes <- function(.) aes(colour=NA, fill="grey20", size=0.5, linetype=1, weight = 1)
   
   required_aes <- c("x")
  
@@ -16,17 +16,17 @@ GeomBar <- proto(Geom, {
     )
   }
  
-  draw <- function(., data, scales, coordinates, ...) {
-    GeomRect$draw(data, scales, coordinates, ...)
+  draw_groups <- function(., data, scales, coordinates, ...) {
+    GeomRect$draw_groups(data, scales, coordinates, ...)
   }
   
   # Documentation -----------------------------------------------
   objname <- "bar"
   desc <- "Bars, rectangles with bases on y-axis"
-  guide_geom <- function(.) "tile"
+  guide_geom <- function(.) "polygon"
   
   icon <- function(.) {
-    rectGrob(c(0.3, 0.7), c(0.4, 0.8), height=c(0.4, 0.8), width=0.3, vjust=1, gp=gpar(fill="grey60", col=NA))
+    rectGrob(c(0.3, 0.7), c(0.4, 0.8), height=c(0.4, 0.8), width=0.3, vjust=1, gp=gpar(fill="grey20", col=NA))
   }
   details <- "<p>The bar geom is used to produce 1d area plots: bar charts for categorical x, and histograms for continuous y.  stat_bin explains the details of these summaries in more detail.  In particular, you can use the <code>weight</code> aesthetic to create weighted histograms and barcharts where the height of the bar no longer represent a count of observations, but a sum over some other variable.  See the examples for a practical example.</p>\n<p>By default, multiple x's occuring in the same place will be stacked a top one another by position_stack.  If you want them to be dodged from side-to-side, check out position_dodge.  Finally, position_fill shows relative propotions at each x by stacking the bars and then stretch or squashing them all to the same height</p>\n"
   
@@ -54,35 +54,34 @@ GeomBar <- proto(Geom, {
     qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(vs))
     qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(gear))
 
-    ggplot(diamonds, aes(x=price, fill=cut)) + geom_bar()
     ggplot(diamonds, aes(x=clarity, fill=cut)) + geom_bar()
-    ggplot(diamonds, aes(x=price, fill=cut)) + geom_bar() + coord_flip()
+    ggplot(diamonds, aes(x=color, fill=cut)) + geom_bar() + coord_flip()
+    ggplot(diamonds, aes(x=price, fill=cut)) + geom_bar()
 
     # Dodged bar charts    
     ggplot(diamonds, aes(x=clarity, fill=cut)) + geom_bar(position="dodge")
     # compare with 
     ggplot(diamonds, aes(x=cut, fill=cut)) + geom_bar() + facet_grid(. ~ clarity)
     
-    # But may be better to use a line plot instead:
+    # But may be better to use a frequency polygons instead:
     ggplot(diamonds, aes(x=clarity, colour=cut)) + 
-      geom_line(aes(group = cut, y = ..count..), stat="bin")
+      geom_freqpoly(aes(group = cut))
     
     # Often we don't want the height of the bar to represent the
     # count of observations, but the sum of some other variable.
-    # For example, the following plot shows the number of movies
-    # in each rating.
-    qplot(rating, data=movies, geom="bar")
-    # If, however, we want to see the number of votes cast in each
-    # category, we need to weight by the votes variable
-    qplot(rating, data=movies, geom="bar", weight=votes)
-    # We could also see the total expenditure for each category:
-    qplot(rating, data=movies, geom="bar", weight=budget)
+    # For example, the following plot shows the number of diamonds
+    # of each colour
+    qplot(color, data=diamonds, geom="bar")
+    # If, however, we want to see the total number of carats in each colour
+    # we need to weight by the carat variable
+    qplot(color, data=diamonds, geom="bar", weight=carat, ylab="carat")
     
     # A bar chart used to display means
     meanprice <- tapply(diamonds$price, diamonds$cut, mean)
     cut <- factor(levels(diamonds$cut), levels = levels(diamonds$cut))
     qplot(cut, meanprice)
     qplot(cut, meanprice, geom="bar", stat="identity")
+    qplot(cut, meanprice, geom="bar", stat="identity", fill = I("grey50"))
   }  
 
 })
\ No newline at end of file
