@@ -9,7 +9,7 @@ GeomBoxplot <- proto(Geom, {
     )
   }
   
-  draw <- function(., data, ..., outlier.colour = "black", outlier.shape = 19, outlier.size = 1) {    
+  draw <- function(., data, ..., outlier.colour = "black", outlier.shape = 16, outlier.size = 1) {    
     defaults <- with(data, data.frame(
       x = x, xmin = xmin, xmax = xmax, 
       colour = colour, size = size, 
@@ -17,14 +17,26 @@ GeomBoxplot <- proto(Geom, {
       stringsAsFactors = FALSE
     ))
     defaults2 <- defaults[c(1,1), ]
-
-    with(data, ggname(.$my_name(), gTree(children = gList(
-      if(length(outliers[[1]]) >= 1) GeomPoint$draw(data.frame(y = outliers[[1]], x = x[rep(1, length(outliers[[1]]))], colour=I(outlier.colour), shape=outlier.shape, size=outlier.size, fill = NA), ...),
+    
+    if (!is.null(data$outliers) && length(data$outliers[[1]] >= 1)) {
+      outliers_grob <- with(data,
+        GeomPoint$draw(data.frame(
+          y = outliers[[1]], x = x[rep(1, length(outliers[[1]]))],
+          colour=I(outlier.colour), shape = outlier.shape, 
+          size = outlier.size, fill = NA), ...
+        )
+      )
+    } else {
+      outliers_grob <- NULL
+    }
+    
+    with(data, ggname(.$my_name(), grobTree(
+      outliers_grob,
       GeomPath$draw(data.frame(y=c(upper, ymax), defaults2), ...),
       GeomPath$draw(data.frame(y=c(lower, ymin), defaults2), ...),
-      GeomBar$draw(data.frame(ymax = upper, ymin = lower, defaults), ...),
-      GeomBar$draw(data.frame(ymax = middle, ymin = middle, defaults), ...)
-    ))))
+      GeomRect$draw(data.frame(ymax = upper, ymin = lower, defaults), ...),
+      GeomRect$draw(data.frame(ymax = middle, ymin = middle, defaults), ...)
+    )))
   }
 
   objname <- "boxplot"
@@ -51,7 +63,7 @@ GeomBoxplot <- proto(Geom, {
   
   default_stat <- function(.) StatBoxplot
   default_pos <- function(.) PositionDodge
-  default_aes <- function(.) aes(weight=1, colour="grey60", fill="white", size=0.5)
+  default_aes <- function(.) aes(weight=1, colour="grey20", fill="white", size=0.5)
   required_aes <- c("x", "lower", "upper", "middle", "ymin", "ymax")
   seealso <- list(
     stat_quantile = "View quantiles conditioned on a continuous variable",
@@ -64,43 +76,47 @@ GeomBoxplot <- proto(Geom, {
   )
   
   examples <- function(.) {
-    p <- ggplot(mtcars, aes(y=mpg, x=factor(cyl)))
+    p <- ggplot(mtcars, aes(factor(cyl), mpg))
     
     p + geom_boxplot()
-    p + stat_boxplot()
+    qplot(factor(cyl), mpg, data = mtcars, geom = "boxplot")
+    
     p + geom_boxplot() + geom_jitter()
     p + geom_boxplot() + coord_flip()
+    qplot(factor(cyl), mpg, data = mtcars, geom = "boxplot") +
+      coord_flip()
     
     p + geom_boxplot(outlier.colour = "green", outlier.size = 3)
     
     # Add aesthetic mappings
-    p + geom_boxplot(aes(fill=cyl))
-    p + geom_boxplot(aes(fill=factor(cyl)))
-    p + geom_boxplot(aes(colour=cyl), size=1)
-    
-    # Dodged boxplots
-    # - automatically split when an aesthetic variable is a factor
-    p + geom_boxplot(aes(colour=factor(am)))
-    p + geom_boxplot(aes(fill=factor(vs)), colour="black")
-    p + geom_boxplot(aes(size=factor(gear)))
+    # Note that boxplots are automatically dodged when any aesthetic is 
+    # a factor
+    p + geom_boxplot(aes(fill = cyl))
+    p + geom_boxplot(aes(fill = factor(cyl)))
+    p + geom_boxplot(aes(fill = factor(vs)))
+    p + geom_boxplot(aes(fill = factor(am)))
     
     # Set aesthetics to fixed value
-    p + geom_boxplot(fill="black", colour="white", size=1)
+    p + geom_boxplot(fill="grey80", colour="#3366FF")
+    qplot(factor(cyl), mpg, data = mtcars, geom = "boxplot", 
+      colour = I("#3366FF"))
 
-    # Scales vs. Coordinate transforms
-    m <- ggplot(movies, aes(y=votes, x=rating, group=round_any(rating,0.5)))
-    m + geom_point()
+    # Scales vs. coordinate transforms -------
+    # Scale transformations occur before the boxplot statistics are computed.
+    # Coordinate transformations occur afterwards.  Observe the effect on the
+    # number of outliers.
+    m <- ggplot(movies, aes(y = votes, x = rating,
+       group = round_any(rating, 0.5)))
     m + geom_boxplot()
     m + geom_boxplot() + scale_y_log10()
-    m + geom_boxplot() + coord_trans(y="log10")
-    m + geom_boxplot() + scale_y_log10() + coord_trans(y="log10")
+    m + geom_boxplot() + coord_trans(y = "log10")
+    m + geom_boxplot() + scale_y_log10() + coord_trans(y = "log10")
     
-    # Boxplots with continuous x
-    qplot(year, budget, data=movies, geom="boxplot")
-    qplot(year, budget, data=movies, geom="boxplot", group=round_any(year, 10, floor))
+    # Boxplots with continuous x:
+    # Use the group aesthetic to group observations in boxplots
+    qplot(year, budget, data = movies, geom = "boxplot")
+    qplot(year, budget, data = movies, geom = "boxplot", 
+      group = round_any(year, 10, floor))
     
-    # Use qplot instead
-    qplot(factor(cyl), mpg, data=mtcars, geom="boxplot")
-    qplot(factor(cyl), mpg, data=mtcars, geom="boxplot") + coord_flip()
   }
 })
