@@ -26,10 +26,12 @@ StatQuantile <- proto(Stat, {
     data <- remove_missing(data, na.rm, c("x", "y"), name = "stat_quantile")
     model <- method(formula, data=data, tau=quantiles, weight=weight, ...)
 
-    yhats <- t(predict(model, data.frame(x=xseq), type="matrix"))
+    yhats <- stats::predict(model, data.frame(x=xseq), type="matrix")
 
     data.frame(
-      y = as.vector(yhats), x = xseq, quantile = rep(quantiles, each=length(xseq))
+      y = as.vector(yhats), 
+      x = xseq, 
+      quantile = rep(quantiles, each=length(xseq))
     )
   }
   
