@@ -10,15 +10,16 @@ theme_gray <- function(base_size = 12) {
     axis.text.x =       theme_text(size = base_size * 0.8 , lineheight = 0.9, colour = "grey50", vjust = 1),
     axis.text.y =       theme_text(size = base_size * 0.8, lineheight = 0.9, colour = "grey50", hjust = 1),
     axis.ticks =        theme_segment(colour = "grey50"),
-    axis.title.x =      theme_text(size = base_size),
-    axis.title.y =      theme_text(size = base_size, angle = 90),
+    axis.title.x =      theme_text(size = base_size, vjust = 1),
+    axis.title.y =      theme_text(size = base_size, angle = 90, vjust = 0),
     axis.ticks.length = unit(0.15, "cm"),
     axis.ticks.margin = unit(0.1, "cm"),
 
     legend.background = theme_rect(colour=NA), 
     legend.key =        theme_rect(fill = "grey95", colour = "white"),
-    legend.text =       theme_text(size = base_size),
-    legend.title =      theme_text(size = base_size, face = "bold", hjust = 0),
+    legend.key.size =   unit(1.2, "lines"),
+    legend.text =       theme_text(size = base_size * 0.8),
+    legend.title =      theme_text(size = base_size * 0.8, face = "bold", hjust = 0),
     legend.position =   "right",
 
     panel.background =  theme_rect(fill = "grey90", colour = NA), 
@@ -33,7 +34,8 @@ theme_gray <- function(base_size = 12) {
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
 
     plot.background =   theme_rect(colour = NA),
-    plot.title =        theme_text(size = base_size * 1.2)
+    plot.title =        theme_text(size = base_size * 1.2),
+    plot.margin =       unit(c(1, 1, 0.5, 0.5), "lines")
   ), class = "options")
 }
 theme_grey <- theme_gray
@@ -49,15 +51,16 @@ theme_bw <- function(base_size = 12) {
     axis.text.x =       theme_text(size = base_size * 0.8 , lineheight = 0.9, vjust = 1),
     axis.text.y =       theme_text(size = base_size * 0.8, lineheight = 0.9, hjust = 1),
     axis.ticks =        theme_segment(colour = "black", size = 0.2),
-    axis.title.x =      theme_text(size = base_size),
-    axis.title.y =      theme_text(size = base_size, angle = 90),
+    axis.title.x =      theme_text(size = base_size, vjust = 1),
+    axis.title.y =      theme_text(size = base_size, angle = 90, vjust = 0),
     axis.ticks.length = unit(0.3, "lines"),
     axis.ticks.margin = unit(0.5, "lines"),
 
     legend.background = theme_rect(colour=NA), 
     legend.key =        theme_rect(colour = "grey80"),
-    legend.text =       theme_text(size = base_size),
-    legend.title =      theme_text(size = base_size, face = "bold", hjust = 0),
+    legend.key.size =   unit(1.2, "lines"),
+    legend.text =       theme_text(size = base_size * 0.8),
+    legend.title =      theme_text(size = base_size * 0.8, face = "bold", hjust = 0),
     legend.position =   "right",
 
     panel.background =  theme_rect(fill = "white", colour = NA), 
@@ -72,7 +75,8 @@ theme_bw <- function(base_size = 12) {
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
 
     plot.background =   theme_rect(colour = NA),
-    plot.title =        theme_text(size = base_size * 1.2)    
+    plot.title =        theme_text(size = base_size * 1.2),
+    plot.margin =       unit(rep(0.5, 4), "lines")
   ), class = "options")
 }
 
